@@ -10,7 +10,7 @@ import pandas as pd
 import xarray as xr
 
 from nowcasting_dataset.config.model import Configuration
-from nowcasting_dataset.consts import NWP_VARIABLE_NAMES, SAT_VARIABLE_NAMES
+from nowcasting_dataset.consts import SAT_VARIABLE_NAMES
 from nowcasting_dataset.data_sources.fake.coordinates import (
     create_random_point_coordinates_osgb,
     make_random_image_coords_osgb,
@@ -159,7 +159,7 @@ def nwp_fake(
     image_size_pixels = configuration.input_data.nwp.nwp_image_size_pixels
     history_seq_length = configuration.input_data.nwp.history_seq_length_60_minutes
     seq_length_60 = configuration.input_data.nwp.seq_length_60_minutes
-    number_nwp_channels = len(configuration.input_data.nwp.nwp_channels)
+    nwp_channels = configuration.input_data.nwp.nwp_channels
 
     if metadata is None:
         t0_datetimes_utc = make_t0_datetimes_utc(batch_size)
@@ -175,7 +175,7 @@ def nwp_fake(
             seq_length=seq_length_60,
             history_seq_length=history_seq_length,
             image_size_pixels=image_size_pixels,
-            channels=NWP_VARIABLE_NAMES[0:number_nwp_channels],
+            channels=nwp_channels,
             freq="60T",
             t0_datetime_utc=t0_datetimes_utc[i],
             x_center_osgb=x_centers_osgb[i],
@@ -253,7 +253,7 @@ def satellite_fake(
     image_size_pixels = configuration.input_data.satellite.satellite_image_size_pixels
     history_seq_length = configuration.input_data.satellite.history_seq_length_5_minutes
     seq_length_5 = configuration.input_data.satellite.seq_length_5_minutes
-    number_satellite_channels = len(configuration.input_data.satellite.satellite_channels)
+    satellite_channels = configuration.input_data.satellite.satellite_channels
 
     if metadata is None:
         t0_datetimes_utc = make_t0_datetimes_utc(batch_size)
@@ -269,7 +269,7 @@ def satellite_fake(
             seq_length=seq_length_5,
             history_seq_length=history_seq_length,
             image_size_pixels=image_size_pixels,
-            channels=SAT_VARIABLE_NAMES[1:number_satellite_channels],
+            channels=satellite_channels,
             t0_datetime_utc=t0_datetimes_utc[i],
             x_center_osgb=x_centers_osgb[i],
             y_center_osgb=y_centers_osgb[i],
@@ -340,7 +340,7 @@ def optical_flow_fake(
     image_size_pixels = configuration.input_data.opticalflow.opticalflow_input_image_size_pixels
     history_seq_length = configuration.input_data.opticalflow.history_seq_length_5_minutes
     seq_length_5 = configuration.input_data.opticalflow.seq_length_5_minutes
-    number_satellite_channels = len(configuration.input_data.opticalflow.opticalflow_channels)
+    satellite_channels = configuration.input_data.opticalflow.opticalflow_channels
 
     if metadata is None:
         t0_datetimes_utc = make_t0_datetimes_utc(batch_size)
@@ -357,7 +357,7 @@ def optical_flow_fake(
             history_seq_length=history_seq_length,
             freq="5T",
             image_size_pixels=image_size_pixels,
-            channels=SAT_VARIABLE_NAMES[0:number_satellite_channels],
+            channels=satellite_channels,
             t0_datetime_utc=t0_datetimes_utc[i],
             x_center_osgb=x_centers_osgb[i],
             y_center_osgb=y_centers_osgb[i],
